summaryrefslogtreecommitdiff
path: root/interface/PluginInterface_Listener.h
diff options
context:
space:
mode:
Diffstat (limited to 'interface/PluginInterface_Listener.h')
-rw-r--r--interface/PluginInterface_Listener.h62
1 files changed, 33 insertions, 29 deletions
diff --git a/interface/PluginInterface_Listener.h b/interface/PluginInterface_Listener.h
index 5648ed8..2fbe95b 100644
--- a/interface/PluginInterface_Listener.h
+++ b/interface/PluginInterface_Listener.h
@@ -1,8 +1,7 @@
/** \file PluginInterface_Listener.h
\brief Define the interface of the plugin of type: listener
\author alpha_one_x86
-\version 0.3
-\date 2010 */
+\licence GPL3, see the file COPYING */
#ifndef PLUGININTERFACE_LISTENER_H
#define PLUGININTERFACE_LISTENER_H
@@ -19,34 +18,39 @@
* */
class PluginInterface_Listener : public QObject
{
- Q_OBJECT
- public:
- /// \brief put this plugin in listen mode
- virtual void listen() = 0;
- /// \brief put close the listen
- virtual void close() = 0;
- /// \brief to get the error string
- virtual const QString errorString() = 0;
- /// \brief set the resources for the plugin
- virtual void setResources(OptionInterface * options,QString writePath,QString pluginPath,bool portableVersion) = 0;
- /// \brief to get the options widget, NULL if not have
- virtual QWidget * options() = 0;
- public slots:
- /// \brief send when copy is finished
- virtual void transferFinished(quint32 orderId,bool withError) = 0;
- /// \brief send when copy is canceled
- virtual void transferCanceled(quint32 orderId) = 0;
- /// \brief to reload the translation, because the new language have been loaded
- virtual void newLanguageLoaded() = 0;
- /* signal to implement
- signals:
- void newState(ListeningState state);
- void newCopy(quint32 orderId,QStringList sources);
- void newCopy(quint32 orderId,QStringList sources,QString destination);
- void newMove(quint32 orderId,QStringList sources);
- void newMove(quint32 orderId,QStringList sources,QString destination);*/
+ Q_OBJECT
+ public:
+ /// \brief put this plugin in listen mode
+ virtual void listen() = 0;
+ /// \brief put close the listen
+ virtual void close() = 0;
+ /// \brief to get the error string
+ virtual const QString errorString() const = 0;
+ /// \brief set the resources for the plugin
+ virtual void setResources(OptionInterface * options,const QString &writePath,const QString &pluginPath,const bool &portableVersion) = 0;
+ /// \brief to get the options widget, NULL if not have
+ virtual QWidget * options() = 0;
+ /// \brief to get a client list
+ virtual QStringList clientsList() const = 0;
+ public slots:
+ /// \brief send when copy is finished
+ virtual void transferFinished(const quint32 &orderId,const bool &withError) = 0;
+ /// \brief send when copy is canceled
+ virtual void transferCanceled(const quint32 &orderId) = 0;
+ /// \brief to reload the translation, because the new language have been loaded
+ virtual void newLanguageLoaded() = 0;
+ signals:
+ void newState(const Ultracopier::ListeningState &state) const;
+ void newCopyWithoutDestination(const quint32 &orderId,const QStringList &sources) const;
+ void newCopy(const quint32 &orderId,const QStringList &sources,const QString &destination) const;
+ void newMoveWithoutDestination(const quint32 &orderId,const QStringList &sources) const;
+ void newMove(const quint32 &orderId,const QStringList &sources,const QString &destination) const;
+ void error(const QString &error) const;
+ void newClientList() const;
+ /// \brief To debug source
+ void debugInformation(const Ultracopier::DebugLevel &level,const QString &fonction,const QString &text,const QString &file,const int &ligne) const;
};
-Q_DECLARE_INTERFACE(PluginInterface_Listener,"first-world.info.ultracopier.PluginInterface.Listener/0.3.0.8");
+Q_DECLARE_INTERFACE(PluginInterface_Listener,"first-world.info.ultracopier.PluginInterface.Listener/1.0.0.0");
#endif // PLUGININTERFACE_LISTENER_H